const request = require('request');

module.exports = class KitsuAPI {
    constructor(debug = false) {
        this.debug = debug;
        this.request = request.defaults({
            "json": true,
            "headers": {
                "Accept": "application/vnd.api+json",
                "Content-Type": "application/vnd.api+json"
            },
            "baseUrl": "https://kitsu.io/api/edge/"
        });
    }
    _get(url, retry = true) {
        if (this.debug)
            console.log(`Making a request to: ${url}`);
        return new Promise((resolve, reject) => {
            this.request.get(url, (err, res, body) => {
                if (err && retry) {
                    if (this.debug)
                        console.warn(`There was an error (${err.code}), retrying...`);
                    return resolve(this._get(url, false));
                } else if (err) {
                    return reject(err);
                } else if (!body.data) {
                    return reject(new Error(`There was an error (${res.statusCode}), no result was found.`));
                } else {
                    return resolve(body.data);
                }
            });
        });
    }
    getAnime(identifier, filter = "text", sort = null) {
        if (!isNaN(identifier)) {
            return this._get("/anime/" + identifier);
        } else {
            return this._get(`/anime?filter[${filter}]=${identifier}`);
        }
    }
    getManga(identifier, filter = "text", sort = null) {
        if (!isNaN(identifier)) {
            return this._get("/manga/" + identifier);
        } else {
            return this._get(`/manga?filter[${filter}]=${identifier}`);
        }
    }
} 